==> hpx_0.9.10.tar.gz: hpx_0.9.10/hpx/plugins/parcelport/mpi/locality.hpp <==
//  Copyright (c) 2007-2014 Hartmut Kaiser
//  Copyright (c) 2013-2014 Thomas Heller
//
//  Distributed under the Boost Software License, Version 1.0. (See accompanying
//  file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)

#ifndef HPX_PARCELSET_POLICIES_MPI_LOCALITY_HPP
#define HPX_PARCELSET_POLICIES_MPI_LOCALITY_HPP

#include <hpx/hpx_fwd.hpp>
#include <hpx/runtime/parcelset/locality.hpp>
#include <hpx/plugins/parcelport/mpi/mpi_environment.hpp>
#include <hpx/util/safe_bool.hpp>

namespace hpx { namespace parcelset
{
    namespace policies { namespace mpi
    {
        class locality
        {
        public:
            locality()
              : rank_(-1)
            {}

            explicit locality(boost::int32_t rank)
              : rank_(rank)
            {}

            boost::int32_t rank() const
            {
                return rank_;
            }

            static const char *type()
            {
                return "mpi";
            }

            operator util::safe_bool<locality>::result_type() const
            {
                return util::safe_bool<locality>()(rank_ != -1);
            }

            void save(util::portable_binary_oarchive & ar) const
            {
                ar.save(rank_);
            }

            void load(util::portable_binary_iarchive & ar)
            {
                ar.load(rank_);
            }

        private:
            friend bool operator==(locality const & lhs, locality const & rhs)
            {
                return lhs.rank_ == rhs.rank_;
            }

            friend bool operator<(locality const & lhs, locality const & rhs)
            {
                return lhs.rank_ < rhs.rank_;
            }

            friend std::ostream & operator<<(std::ostream & os, locality const & loc)
            {
                boost::io::ios_flags_saver ifs(os);
                os << loc.rank_;

                return os;
            }

            boost::int32_t rank_;
        };
    }}
}}

#endif

==> hpx_1.0.0.tar.gz: hpx_1.0.0/hpx/plugins/parcelport/mpi/locality.hpp <==
//  Copyright (c) 2007-2014 Hartmut Kaiser
//  Copyright (c) 2013-2014 Thomas Heller
//
//  Distributed under the Boost Software License, Version 1.0. (See accompanying
//  file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)

#ifndef HPX_PARCELSET_POLICIES_MPI_LOCALITY_HPP
#define HPX_PARCELSET_POLICIES_MPI_LOCALITY_HPP

#include <hpx/config.hpp>

#if defined(HPX_HAVE_PARCELPORT_MPI)

#include <hpx/plugins/parcelport/mpi/mpi_environment.hpp>
#include <hpx/runtime/parcelset/locality.hpp>
#include <hpx/runtime/serialization/serialize.hpp>

#include <boost/io/ios_state.hpp>

#include <cstdint>

namespace hpx { namespace parcelset
{
    namespace policies { namespace mpi
    {
        class locality
        {
        public:
            locality()
              : rank_(-1)
            {}

            explicit locality(std::int32_t rank)
              : rank_(rank)
            {}

            std::int32_t rank() const
            {
                return rank_;
            }

            static const char *type()
            {
                return "mpi";
            }

            explicit operator bool() const HPX_NOEXCEPT
            {
                return rank_ != -1;
            }

            void save(serialization::output_archive & ar) const
            {
                ar << rank_;
            }

            void load(serialization::input_archive & ar)
            {
                ar >> rank_;
            }

        private:
            friend bool operator==(locality const & lhs, locality const & rhs)
            {
                return lhs.rank_ == rhs.rank_;
            }

            friend bool operator<(locality const & lhs, locality const & rhs)
            {
                return lhs.rank_ < rhs.rank_;
            }

            friend std::ostream & operator<<(std::ostream & os, locality const & loc)
            {
                boost::io::ios_flags_saver ifs(os);
                os << loc.rank_;

                return os;
            }

            std::int32_t rank_;
        };
    }}
}}

#endif

#endif
